Struct collected::UniqueHashSet [−][src]
pub struct UniqueHashSet<A>(_);
A collection that takes unique values into a set.
It maintains a HashSet internally. When it is
built from iterator or extended, it expects unique input values.
Otherwise, it empties out the internal and ignore future values.
Implementations